@@ -1,7 +1,7 @@
 /*
  *  fileresourcesettings.h  -  settings for calendar resource accessed via file system
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2020-2022 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2020-2023 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -29,12 +29,12 @@ public:
     /** A shared pointer to a FileResourceSettings object. */
     using Ptr = QSharedPointer<FileResourceSettings>;
 
-    enum StorageType { NoStorage, File, Directory };
+    enum Storage { None, File, Directory };
 
     struct CommandError
     {
-        QString             id;
-        KAEvent::CmdErrType error;
+        QString         id;
+        KAEvent::CmdErr error;
     };
 
     FileResourceSettings() = default;
@@ -45,7 +45,7 @@ public:
     /** Initialises the settings. This should only be used by the
      *  ResourceMigrator.
      */
-    FileResourceSettings(StorageType, const QUrl& location, CalEvent::Types alarmTypes,
+    FileResourceSettings(Storage, const QUrl& location, CalEvent::Types alarmTypes,
                          const QString& displayName, const QColor& backgroundColour,
                          CalEvent::Types enabledTypes, CalEvent::Types standardTypes,
                          bool readOnly);
@@ -85,7 +85,7 @@ public:
     QString displayLocation() const;
 
     /** Return the resource's storage type. */
-    StorageType storageType() const;
+    Storage storageType() const;
 
     /** Return the resource's display name. */
     QString displayName() const;
@@ -266,14 +266,14 @@ public:
      *  command errors.
      *  @return command error types, indexed by event ID.
      */
-    QHash<QString, KAEvent::CmdErrType> commandErrors() const;
+    QHash<QString, KAEvent::CmdErr> commandErrors() const;
 
     /** Set the command error data for all events in the resource which have
      *  command errors.
      *  @param cmdErrors  command error types, indexed by event ID.
      *  @param save       whether to save the config
      */
-    void setCommandErrors(const QHash<QString, KAEvent::CmdErrType>& cmdErrors, bool save = true);
+    void setCommandErrors(const QHash<QString, KAEvent::CmdErr>& cmdErrors, bool save = true);
 
 protected:
     /** Set the resource's unique ID.
@@ -287,7 +287,7 @@ private:
     bool                  validate();
     CalEvent::Types       readAlarmTypes(const char* key) const;
     static QString        alarmTypesString(CalEvent::Types alarmTypes);
-    static StorageType    storageType(const QUrl& url);
+    static Storage        storageType(const QUrl& url);
     ResourceType::Changes handleEnabledChange(CalEvent::Types oldEnabled, CalEvent::Types oldStandard, bool typesChanged, bool save);
     ResourceType::Changes handleStandardChange(CalEvent::Types oldStandard, bool sync);
     void writeConfigDisplayName(bool save);
@@ -308,9 +308,9 @@ private:
     QString           mDisplayLocation;  // displayable location of file or directory
     QString           mDisplayName;      // name for user display
     QByteArray        mHash;             // hash of the calendar file contents
-    QHash<QString, KAEvent::CmdErrType> mCommandErrors;  // event IDs and their command error types
+    QHash<QString, KAEvent::CmdErr> mCommandErrors;  // event IDs and their command error types
     QColor            mBackgroundColour; // background colour to display the resource and its alarms
-    StorageType       mStorageType {NoStorage};      // how the calendar is stored
+    Storage           mStorageType {Storage::None};  // how the calendar is stored
     CalEvent::Types   mAlarmTypes {CalEvent::EMPTY}; // alarm types which the resource contains
     CalEvent::Types   mEnabled {CalEvent::EMPTY};    // alarm types for which the resource is enabled
     CalEvent::Types   mStandard {CalEvent::EMPTY};   // alarm types for which the resource is the standard resource
