@@ -21,8 +21,6 @@
 
 #include <QTimer>
 
-#include <kwidgetsaddons_version.h>
-
 using namespace KAlarmCal;
 
 
@@ -234,7 +232,7 @@ DirResourceImportTypeWidget::DirResourceImportTypeWidget(CalEvent::Type alarmTyp
     mUi = new Ui_DirResourceImportTypeWidget;
     mUi->setupUi(this);
 
-    const QVector<Resource> resources = Resources::allResources<FileResource>(alarmType, Resources::DefaultFirst | Resources::DisplayName);
+    const QList<Resource> resources = Resources::allResources<FileResource>(alarmType, Resources::DefaultFirst | Resources::DisplayName);
     if (resources.isEmpty())
     {
         mUi->mergeRadio->setVisible(false);
@@ -250,11 +248,7 @@ DirResourceImportTypeWidget::DirResourceImportTypeWidget(CalEvent::Type alarmTyp
     connect(mUi->optionGroup, &QButtonGroup::idToggled, this, &DirResourceImportTypeWidget::importTypeSelected);
 
     mUi->pathRequester->setMode(KFile::File);
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 108, 0)
     mUi->pathRequester->setNameFilters({QStringLiteral("%1 (*.ics)").arg(i18nc("@item:inlistbox File type selection filter", "Calendar files"))});
-#else
-    mUi->pathRequester->setFilter(QStringLiteral("*.ics|%1").arg(i18nc("@item:inlistbox File type selection filter", "Calendar files")));
-#endif
     mUi->statusLabel->setText(QString());
     mUi->pathRequester->setFocus();
     mUi->pathRequester->installEventFilter(this);
@@ -396,7 +390,7 @@ void DirResourceImportTypeWidget::validate()
         if (mStatJob)
             mStatJob->kill();
         mCheckingDir = false;
-        mStatJob = KIO::statDetails(currentUrl, KIO::StatJob::SourceSide, KIO::StatDetail::StatNoDetails, KIO::HideProgressInfo);
+        mStatJob = KIO::stat(currentUrl, KIO::StatJob::SourceSide, KIO::StatDetail::StatNoDetails, KIO::HideProgressInfo);
         connect(mStatJob, &KIO::StatJob::result, this, &DirResourceImportTypeWidget::slotStatJobResult);
 
         // Disable the OK button until the file's status is determined.
@@ -449,7 +443,7 @@ void DirResourceImportTypeWidget::slotStatJobResult(KJob* job)
             // The file doesn't exist (as expected), so check that the file's
             // directory is writable.
             mCheckingDir = true;
-            mStatJob = KIO::statDetails(KIO::upUrl(mUi->pathRequester->url()),
+            mStatJob = KIO::stat(KIO::upUrl(mUi->pathRequester->url()),
                                         KIO::StatJob::SourceSide,
                                         KIO::StatDetail::StatDefaultDetails,
                                         KIO::HideProgressInfo);
@@ -500,4 +494,7 @@ void DirResourceImportTypeWidget::setStatus(bool ok, const QString& errorMessage
     Q_EMIT status(ok);
 }
 
+#include "moc_dirresourceimportdialog_p.cpp"
+#include "moc_dirresourceimportdialog.cpp"
+
 // vim: et sw=4:
